<?php

namespace Litecms\Slider\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Slider\Http\Requests\BannerSliderRequest;
use Litecms\Slider\Interfaces\BannerSliderRepositoryInterface;
use Litecms\Slider\Models\BannerSlider;

/**
 * Resource controller class for banner_slider.
 */
class BannerSliderResourceController extends BaseController
{

    /**
     * Initialize banner_slider resource controller.
     *
     * @param type BannerSliderRepositoryInterface $banner_slider
     *
     * @return null
     */
    public function __construct(BannerSliderRepositoryInterface $banner_slider)
    {
        parent::__construct();
        $this->repository = $banner_slider;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Slider\Repositories\Criteria\BannerSliderResourceCriteria::class);
    }

    /**
     * Display a list of banner_slider.
     *
     * @return Response
     */
    public function index(BannerSliderRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Slider\Repositories\Presenter\BannerSliderPresenter::class)
                ->$function();
        }

        $banner_sliders = $this->repository->paginate();

        return $this->response->title(trans('slider::banner_slider.names'))
            ->view('slider::banner_slider.index', true)
            ->data(compact('banner_sliders'))
            ->output();
    }

    /**
     * Display banner_slider.
     *
     * @param Request $request
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function show(BannerSliderRequest $request, BannerSlider $banner_slider)
    {

        if ($banner_slider->exists) {
            $view = 'slider::banner_slider.show';
        } else {
            $view = 'slider::banner_slider.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('slider::banner_slider.name'))
            ->data(compact('banner_slider'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new banner_slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BannerSliderRequest $request)
    {

        $banner_slider = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('slider::banner_slider.name')) 
            ->view('slider::banner_slider.create', true) 
            ->data(compact('banner_slider'))
            ->output();
    }

    /**
     * Create new banner_slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BannerSliderRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $banner_slider                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('slider::banner_slider.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('slider/banner_slider/' . $banner_slider->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/slider/banner_slider'))
                ->redirect();
        }

    }

    /**
     * Show banner_slider for editing.
     *
     * @param Request $request
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function edit(BannerSliderRequest $request, BannerSlider $banner_slider)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('slider::banner_slider.name'))
            ->view('slider::banner_slider.edit', true)
            ->data(compact('banner_slider'))
            ->output();
    }

    /**
     * Update the banner_slider.
     *
     * @param Request $request
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function update(BannerSliderRequest $request, BannerSlider $banner_slider)
    {
        try {
            $attributes = $request->all();

            $banner_slider->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('slider::banner_slider.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('slider/banner_slider/' . $banner_slider->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/banner_slider/' . $banner_slider->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the banner_slider.
     *
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function destroy(BannerSliderRequest $request, BannerSlider $banner_slider)
    {
        try {

            $banner_slider->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('slider::banner_slider.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('slider/banner_slider/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/banner_slider/' . $banner_slider->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple banner_slider.
     *
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function delete(BannerSliderRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('slider::banner_slider.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('slider/banner_slider'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/slider/banner_slider'))
                ->redirect();
        }

    }

    /**
     * Restore deleted banner_sliders.
     *
     * @param Model   $banner_slider
     *
     * @return Response
     */
    public function restore(BannerSliderRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('slider::banner_slider.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/slider/banner_slider'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/slider/banner_slider/'))
                ->redirect();
        }

    }

}
